%define anolis_release 1
Summary:       Library of functions for manipulating TIFF format image files
Name:          libtiff
Version:       4.6.0
Release:       %{anolis_release}%{?dist}
License:       libtiff
URL:           http://www.simplesystems.org/libtiff/

Source:        http://download.osgeo.org/libtiff/tiff-%{version}.tar.gz
#xz

Patch0:        libtiff-am-version.patch

# from upstream, for <=4.6.0, RHEL-52926
# https://gitlab.com/libtiff/libtiff/-/commit/3705f82b6483c7906cf08cd6b9dcdcd59c61d779
Patch1:        libtiff-4.6.0-CVE-2024-7006.patch

Patch2:        CVE-2023-6277.patch
Patch3:        CVE-2023-6228.patch

BuildRequires: gcc, gcc-c++
BuildRequires: zlib-devel libjpeg-devel jbigkit-devel libzstd-devel libwebp-devel glut-devel xz-devel
BuildRequires: python3-sphinx
BuildRequires: cmake

%description
The libtiff package contains a library of functions for manipulating
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:       Development tools for programs which will use the libtiff library
Requires:      %{name} = %{version}-%{release}

%description devel
This package contains the header files and documentation necessary for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.

%package static
Summary:     Static TIFF image format file library
Requires:    %{name}-devel = %{version}-%{release}

%description static
The libtiff-static package contains the statically linkable version of libtiff.
Linking to static libraries is discouraged for most applications, but it is
necessary for some boot packages.

%package tools
Summary:    Command-line utility programs for manipulating TIFF files
Requires:   %{name} = %{version}-%{release}

%description tools
This package contains command-line programs for manipulating TIFF format
image files using the libtiff library.

%prep
%autosetup -p1 -n tiff-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake
%cmake_build

%install
%cmake_install

# remove what we didn't want installed
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/

%generate_compatibility_deps

%check
%ctest

%files
%dir %{abidir}
%license LICENSE.md
%{_libdir}/libtiff.so.*
%{_libdir}/libtiffxx.so.*
%{abidir}/libtiff*.dump

%files doc
%doc README.md RELEASE-DATE VERSION

%files devel
%doc TODO ChangeLog doc/html-prebuilt/*
%{_includedir}/*
%{_libdir}/libtiff.so
%{_libdir}/libtiffxx.so
%{_libdir}/pkgconfig/libtiff*.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/tiff
%{_mandir}/man3/*

%files tools
%{_bindir}/*
%{_mandir}/man1/*
%{abidir}/tiff*-option.list

%changelog
* Wed Feb 19 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.6.0-1
- Sync up from CentOS Stream libtiff-4.6.0-1(tdawson@redhat.com)

* Thu Jan 04 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.5.1-5
- Fix CVE-2023-6228

* Tue Nov 28 2023 Funda Wang <fundawang@yeah.net> - 4.5.1-4
- Fix CVE-2023-6277

* Tue Oct 31 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.5.1-3
- Fix CVE-2023-1916

* Tue Oct 17 2023 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 4.5.1-2
- Fix CVE-2023-41175 CVE-2023-40745

* Wed Jun 14 2023 Funda Wang <fundawang@yeah.net> - 4.5.1-1
- New version 4.5.1

* Sat Mar 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-3
- Add patches fixing CVE-2023-0975 .. 0804

* Sat Feb 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-2
- Add patch fixing CVE-2022-48281

* Wed Jan 18 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-1
- New version 4.5.0
- Build using cmake
- Drop static as cmake does not support building it right now
- Split out tiffgt as what debian does

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.4.0-2
- optimise spec file & add doc package

* Mon Sep 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 4.4.0-1
- update to 4.4.0

* Tue Apr 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.3.0-2
- fix tiffconf.h error

* Fri Apr 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.3.0-1
- Init from upstream version 4.3.0
